@@ -3,7 +3,7 @@ use crate::currency::Cash;
 use crate::currency::converter::CurrencyConverter;
 use crate::formatting;
 use crate::localities::Country;
-use crate::taxes::{IncomeType, TaxExemption};
+use crate::taxes::{self, IncomeType, TaxExemption};
 use crate::time::DateOptTime;
 use crate::trades::calculate_price;
 use crate::types::{Date, Decimal};
@@ -227,26 +227,30 @@ impl StockSell {
             let source_total_cost = source_details.total_cost(currency, converter)?;
             let source_total_local_cost = source_details.total_cost(country.currency, converter)?;
 
-            let mut tax_exemptible = false;
             for tax_exemption in tax_exemptions {
-                let (exemptible, force) = tax_exemption.is_applicable();
-                tax_exemptible |= exemptible;
-                if force {
-                    source_details.tax_exemption_applied = true;
-                    break;
-                }
-            }
+                match tax_exemption {
+                    TaxExemption::LongTermOwnership => {
+                        if let Some(years) = taxes::long_term_ownership::is_deductible(source.execution_date, self.execution_date) {
+                            let source_local_revenue = local_execution(price * source_quantity)?;
+                            let source_local_commission = local_conclusion(
+                                commission * source_quantity / self.quantity)?;
 
-            if tax_exemptible && !source_details.tax_exemption_applied {
-                let source_local_revenue = local_execution(price * source_quantity)?;
-                let source_local_commission = local_conclusion(
-                    commission * source_quantity / self.quantity)?;
+                            let source_local_profit = source_local_revenue
+                                .sub(source_local_commission).unwrap()
+                                .sub(source_total_local_cost).unwrap();
 
-                let source_local_profit = source_local_revenue
-                    .sub(source_local_commission).unwrap()
-                    .sub(source_total_local_cost).unwrap();
-
-                source_details.tax_exemption_applied = source_local_profit.is_positive();
+                            source_details.long_term_ownership_deductible.replace(LtoDeductible {
+                                profit: std::cmp::max(dec!(0), source_local_profit.amount),
+                                years,
+                            });
+                            break;
+                        }
+                    },
+                    TaxExemption::TaxFree => {
+                        source_details.tax_exemption_applied = true;
+                        break;
+                    },
+                };
             }
 
             total_quantity += source_quantity;
@@ -374,6 +378,10 @@ pub struct SellDetails {
 }
 
 impl SellDetails {
+    pub fn long_term_ownership(&self) -> bool {
+        self.fifo.iter().any(|trade| trade.long_term_ownership_deductible.is_some())
+    }
+
     pub fn tax_exemption_applied(&self) -> bool {
         if self.fifo.iter().any(|trade| trade.tax_exemption_applied) {
             return true;
@@ -398,6 +406,7 @@ pub struct FifoDetails {
     cost: PurchaseTotalCost,
 
     pub tax_exemption_applied: bool,
+    pub long_term_ownership_deductible: Option<LtoDeductible>,
 }
 
 pub enum StockSourceDetails {
@@ -451,6 +460,7 @@ impl FifoDetails {
             cost: source.cost.clone(),
 
             tax_exemption_applied: false,
+            long_term_ownership_deductible: None,
         })
     }
 
@@ -564,4 +574,10 @@ impl PurchaseTransaction {
     fn new(date: Date, type_: PurchaseCostType, cost: Cash) -> PurchaseTransaction {
         PurchaseTransaction {date, type_, cost}
     }
+}
+
+#[allow(dead_code)] // FIXME(konishchev): Remove
+pub struct LtoDeductible {
+    profit: Decimal,
+    years: u32,
 }
\ No newline at end of file
